/******************************************************************************
 *
 * Copyright (c) 2004 Tatsuo Nagamatsu <nagamatu@sm.sony.co.jp>
 *
 * File: flite.h
 *
 * Release: 
 *
 * Description:
 *              Public API of Flite Library
 *
 *****************************************************************************/

/*
 * MEMO:
 *
 * 1. How to check whether the flite speech synthesis engine is busy or not?
 *
 *			if (FtrGet(kFliteCreator, kFliteFtrNumBusy, &value) == errNone) {
 *				Engine is busy
 *			} else {
 *				Engine is ready
 *			}
 * 
 * 2. How to speech a text?
 *
 *			Get the reference number of flite library and use next API:
 *				flite_text_to_speech(refNum, text, NULL, "play");
 *			If the third argument - voice is NULL, flite library uses the
 *			default voice. The last arguments must be "play". This is reserved
 *			for the feature functionality and is currently ignored.
 *
 * 3. How to detect the end of speech?
 *
 *			Check the notification (notifyType == kFliteCreator)
 *
 * 4. Be care not use SysLibRemove while flite engine is busy.
 * 5. Check the dynamic heap is enough for using flite engine.
 *
 */

#ifndef __FLITE_H__
#define __FLITE_H__

#include <PalmTypes.h>

/********************************************************************
 * Constants
 ********************************************************************/

#define kFliteType					sysFileTLibrary
#define kFliteCreator				'Fest'
#define kFliteName					"flite"	

#define kFliteFtrNumBusy			0

/********************************************************************
 * Traps
 ********************************************************************/

#define kFliteTrapText2Speech		(sysLibTrapCustom + 3)

/********************************************************************
 * Structures
 ********************************************************************/

/********************************************************************
 * Prototypes
 ********************************************************************/
#ifdef __cplusplus
extern "C" {
#endif

UInt32 flite_text_to_speech(UInt16 refNum, const char *text, void *voice, const char *outtype)
			SYS_TRAP(kFliteTrapText2Speech);

#ifdef __cplusplus 
}
#endif

#endif 	//__FLITE_H__

